@@ -190,7 +190,7 @@ def add_top_level_run_arguments(parser: argparse.ArgumentParser) -> None:
     run_group.add_argument(
         "--resume",
         action="store_true",
-        help="Pass --resume flag to Claude Desktop to resume the last conversation",
+        help="Pass --resume flag to Claude Code to resume the last conversation",
     )
     run_group.add_argument(
         "--force",
@@ -322,6 +322,13 @@ def create_parser(
     except ImportError:
         pass
 
+    try:
+        from .agent_manager_parser import add_agent_manager_subparser
+
+        add_agent_manager_subparser(subparsers)
+    except ImportError:
+        pass
+
     # Import and add additional command parsers from commands module
     try:
         from ..commands.aggregate import add_aggregate_parser
@@ -331,6 +338,10 @@ def create_parser(
         from ..commands.cleanup import add_cleanup_parser
 
         add_cleanup_parser(subparsers)
+        
+        from ..commands.doctor import add_doctor_parser
+        
+        add_doctor_parser(subparsers)
     except ImportError:
         # Commands module may not be available during testing or refactoring
         pass
