@@ -27,59 +27,53 @@ def timeout_handler(timeout_seconds: float = 5.0):
     """
     def decorator(func: Callable) -> Callable:
         @functools.wraps(func)
-        async def wrapper(self, *args, **kwargs):
+        async def wrapper(*args, **kwargs):
             handler_name = func.__name__
             start_time = time.time()
             
             try:
                 # Create a task with timeout
                 result = await asyncio.wait_for(
-                    func(self, *args, **kwargs),
+                    func(*args, **kwargs),
                     timeout=timeout_seconds
                 )
                 
                 elapsed = time.time() - start_time
                 if elapsed > timeout_seconds * 0.8:  # Warn if close to timeout
-                    self.logger.warning(
-                        f"⚠️ Handler {handler_name} took {elapsed:.2f}s "
-                        f"(close to {timeout_seconds}s timeout)"
-                    )
+                    # Try to get logger from closure scope or fallback to print
+                    try:
+                        import logging
+                        logger = logging.getLogger(__name__)
+                        logger.warning(
+                            f"⚠️ Handler {handler_name} took {elapsed:.2f}s "
+                            f"(close to {timeout_seconds}s timeout)"
+                        )
+                    except:
+                        print(f"⚠️ Handler {handler_name} took {elapsed:.2f}s (close to {timeout_seconds}s timeout)")
                     
                 return result
                 
             except asyncio.TimeoutError:
                 elapsed = time.time() - start_time
-                self.logger.error(
-                    f"❌ Handler {handler_name} timed out after {elapsed:.2f}s"
-                )
-                
-                # Try to send error response to client if we have their sid
-                if args and isinstance(args[0], str):  # First arg is usually sid
-                    sid = args[0]
-                    try:
-                        # Use a short timeout for error response
-                        await asyncio.wait_for(
-                            self.emit_to_client(
-                                sid, 
-                                "error",
-                                {
-                                    "message": f"Handler {handler_name} timed out",
-                                    "handler": handler_name,
-                                    "timeout": timeout_seconds
-                                }
-                            ),
-                            timeout=1.0
-                        )
-                    except:
-                        pass  # Best effort error notification
+                # Try to get logger from closure scope or fallback to print
+                try:
+                    import logging
+                    logger = logging.getLogger(__name__)
+                    logger.error(f"❌ Handler {handler_name} timed out after {elapsed:.2f}s")
+                except:
+                    print(f"❌ Handler {handler_name} timed out after {elapsed:.2f}s")
                         
                 return None
                 
             except Exception as e:
                 elapsed = time.time() - start_time
-                self.logger.error(
-                    f"❌ Handler {handler_name} failed after {elapsed:.2f}s: {e}"
-                )
+                # Try to get logger from closure scope or fallback to print
+                try:
+                    import logging
+                    logger = logging.getLogger(__name__)
+                    logger.error(f"❌ Handler {handler_name} failed after {elapsed:.2f}s: {e}")
+                except:
+                    print(f"❌ Handler {handler_name} failed after {elapsed:.2f}s: {e}")
                 raise
                 
         return wrapper
@@ -167,8 +161,13 @@ class ConnectionEventHandler(BaseEventHandler):
                 
                 for sid in list(self.clients):
                     try:
-                        # Send ping and record time
-                        await self.sio.emit('ping', {'timestamp': current_time}, room=sid)
+                        # Send ping and record time (using new schema)
+                        await self.sio.emit('ping', {
+                            'type': 'system',
+                            'subtype': 'ping',
+                            'timestamp': current_time,
+                            'source': 'server'
+                        }, room=sid)
                         self.last_ping_times[sid] = current_time
                         
                         # Update connection metrics
@@ -290,16 +289,35 @@ class ConnectionEventHandler(BaseEventHandler):
             self.logger.info(f"📱 User Agent: {user_agent[:100]}...")
             self.logger.info(f"📈 Total clients now: {len(self.clients)}")
 
-            # Send initial status immediately with enhanced data
+            # Get monitor build info
+            monitor_build_info = {}
+            try:
+                from ....services.monitor_build_service import get_monitor_build_service
+                monitor_service = get_monitor_build_service()
+                monitor_build_info = monitor_service.get_build_info_sync()
+            except Exception as e:
+                self.logger.debug(f"Could not get monitor build info: {e}")
+                monitor_build_info = {
+                    "monitor": {"version": "1.0.0", "build": 1, "formatted_build": "0001"},
+                    "mpm": {"version": "unknown", "build": "unknown"}
+                }
+
+            # Send initial status immediately with enhanced data (using new schema)
             status_data = {
-                "server": "claude-mpm-python-socketio",
+                "type": "connection",
+                "subtype": "status",
                 "timestamp": datetime.utcnow().isoformat() + "Z",
-                "clients_connected": len(self.clients),
+                "source": "server",
                 "session_id": self.server.session_id,
-                "claude_status": self.server.claude_status,
-                "claude_pid": self.server.claude_pid,
-                "server_version": "2.0.0",
-                "client_id": sid,
+                "data": {
+                    "server": "claude-mpm-python-socketio",
+                    "clients_connected": len(self.clients),
+                    "claude_status": self.server.claude_status,
+                    "claude_pid": self.server.claude_pid,
+                    "server_version": "2.0.0",
+                    "client_id": sid,
+                    "build_info": monitor_build_info,
+                }
             }
 
             try:
@@ -308,9 +326,17 @@ class ConnectionEventHandler(BaseEventHandler):
                     sid,
                     "welcome",
                     {
-                        "message": "Connected to Claude MPM Socket.IO server",
-                        "client_id": sid,
-                        "server_time": datetime.utcnow().isoformat() + "Z",
+                        "type": "connection",
+                        "subtype": "welcome",
+                        "timestamp": datetime.utcnow().isoformat() + "Z",
+                        "source": "server",
+                        "session_id": self.server.session_id,
+                        "data": {
+                            "message": "Connected to Claude MPM Socket.IO server",
+                            "client_id": sid,
+                            "server_time": datetime.utcnow().isoformat() + "Z",
+                            "build_info": monitor_build_info,
+                        }
                     },
                 )
 
@@ -325,7 +351,7 @@ class ConnectionEventHandler(BaseEventHandler):
 
         @self.sio.event
         @timeout_handler(timeout_seconds=3.0)
-        async def disconnect(sid):
+        async def disconnect(sid, *args):
             """Handle client disconnection.
 
             WHY: We need to clean up client tracking when they disconnect
@@ -355,12 +381,17 @@ class ConnectionEventHandler(BaseEventHandler):
             to update their UI or verify connection health.
             """
             status_data = {
-                "server": "claude-mpm-python-socketio",
+                "type": "connection",
+                "subtype": "status",
                 "timestamp": datetime.utcnow().isoformat() + "Z",
-                "clients_connected": len(self.clients),
+                "source": "server",
                 "session_id": self.server.session_id,
-                "claude_status": self.server.claude_status,
-                "claude_pid": self.server.claude_pid,
+                "data": {
+                    "server": "claude-mpm-python-socketio",
+                    "clients_connected": len(self.clients),
+                    "claude_status": self.server.claude_status,
+                    "claude_pid": self.server.claude_pid,
+                }
             }
             await self.emit_to_client(sid, "status", status_data)
 
@@ -401,7 +432,13 @@ class ConnectionEventHandler(BaseEventHandler):
             for filtered event streaming.
             """
             channels = data.get("channels", ["*"]) if data else ["*"]
-            await self.emit_to_client(sid, "subscribed", {"channels": channels})
+            await self.emit_to_client(sid, "subscribed", {
+                "type": "connection",
+                "subtype": "subscribed",
+                "timestamp": datetime.utcnow().isoformat() + "Z",
+                "source": "server",
+                "data": {"channels": channels}
+            })
 
         @self.sio.event
         @timeout_handler(timeout_seconds=5.0)
@@ -415,10 +452,24 @@ class ConnectionEventHandler(BaseEventHandler):
             self.logger.info(f"🔵 Received claude_event from {sid}: {data}")
             
             # Check if this is a hook event and route to HookEventHandler
-            # Hook events have types like "hook.user_prompt", "hook.pre_tool", etc.
+            # Hook events can have either:
+            # 1. Normalized format: type="hook", subtype="pre_tool"
+            # 2. Legacy format: type="hook.pre_tool"
             if isinstance(data, dict):
                 event_type = data.get("type", "")
-                if isinstance(event_type, str) and event_type.startswith("hook."):
+                event_subtype = data.get("subtype", "")
+                
+                # Check for both normalized and legacy formats
+                is_hook_event = False
+                if isinstance(event_type, str):
+                    # Legacy format: type="hook.something"
+                    if event_type.startswith("hook."):
+                        is_hook_event = True
+                    # Normalized format: type="hook" with any subtype
+                    elif event_type == "hook":
+                        is_hook_event = True
+                
+                if is_hook_event:
                     # Get the hook handler if available
                     hook_handler = None
                     # Check if event_registry exists and has handlers
@@ -508,7 +559,8 @@ class ConnectionEventHandler(BaseEventHandler):
             elif event_name == 'ToolCall':
                 normalized['type'] = 'tool'
             elif event_name == 'UserPrompt':
-                normalized['type'] = 'hook.user_prompt'
+                normalized['type'] = 'hook'
+                normalized['subtype'] = 'user_prompt'
             else:
                 # Default to system type for unknown events
                 normalized['type'] = 'system'
